@@ -118,7 +118,7 @@ void VncClientThread::cursorShapeHandlerStatic(rfbClient *cl, int xhot, int yhot
     QPixmap cursorPixmap(QPixmap::fromImage(cursorImg));
     cursorPixmap.setMask(QBitmap::fromImage(alpha));
 
-    Q_EMIT t->gotCursor({cursorPixmap, xhot, yhot});
+    Q_EMIT t->gotCursor(QCursor{cursorPixmap, xhot, yhot});
 }
 
 void VncClientThread::setClientColorDepth(rfbClient* cl, VncClientThread::ColorDepth cd)
@@ -305,7 +305,7 @@ rfbCredential *VncClientThread::credentialHandler(int credentialType)
 void VncClientThread::outputHandler(const char *format, va_list args)
 {
     QString message;
-    message.vsprintf(format, args);
+    message.vasprintf(format, args);
 
     message = message.trimmed();
 
